@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.0506';
+our $VERSION = '0.0507';
 
 use Moo;
 use strictures 2;
@@ -37,7 +37,7 @@ has stopwords => (
 
 has punctuation => (
     is      => 'ro',
-    default => sub { qr/(?!-)[[:punct:]]/ },
+    default => sub { qr/(?!')[[:punct:]]/ },
 );
 
 
@@ -173,7 +173,7 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.0506
+version 0.0507
 
 =head1 SYNOPSIS
 
@@ -225,7 +225,7 @@ Regular expression to be used to parse-out unwanted punctuation.  Giving the
 constructor a value of C<''> or C<0> will override this and not exclude any
 characters from the results.
 
-Default: (?!-)[[:punct:]]
+Default: qr/(?!')[[:punct:]]/
 
 Note that the default does not exclude the single quote.
 
